//-----------------------------------------------------------------------------
//
//   relctrl.cpp
//
//   Implementation of the class RelayControl (Interface to the relays)
//
//    2002-2007 by Bernd-Ludwig Wenning
//
//-----------------------------------------------------------------------------
//
//  This file is part of RC4.
//
//    RC4 is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    RCM is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with RC4; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//-----------------------------------------------------------------------------

#include "relctrl.h"

// Constructor: Open the handle for the serial port
RelayControl::RelayControl(char *port)
{
  hcom=CreateFile(port, GENERIC_READ | GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
  SwitchOff(true);
}

// Empty constructor
RelayControl::RelayControl()
{
}

// Destructor: Close the handle for the serial port
RelayControl::~RelayControl()
{
  CloseHandle(hcom);
}

// Switch the relay on
void RelayControl::SwitchOn(bool dtr)
{
    bool dcbtest;
    if(GetCommState(hcom, &dcb))
    {
      if (dtr){
         dcb.fDtrControl=DTR_CONTROL_ENABLE;
      } else {
         dcb.fRtsControl=RTS_CONTROL_ENABLE;
      }
      dcbtest=SetCommState(hcom, &dcb);
      if(dcbtest)
      {
        // New state successfully set
      }
      else
      {
        // Error handling: Writing to port not possible
      }
    }
    else
    {
      // Error handling: Reading from port not possible
    }
}

// Switch the relay off
void RelayControl::SwitchOff(bool dtr)
{
  bool dcbtest;
    if(GetCommState(hcom, &dcb))
    {
      if (dtr){
         dcb.fDtrControl=DTR_CONTROL_DISABLE;
      } else {
         dcb.fRtsControl=RTS_CONTROL_DISABLE;
      }
      dcbtest=SetCommState(hcom, &dcb);
      if(dcbtest)
      {
        // New state successfully set
      }
      else
      {
        // Error handling: Writing to port not possible
      }
    }
    else
    {
      // Error handling: Reading from port not possible
    }
}
